%% Script for global instability study of LDMI : 
% ------------------------------------------
%
% Author : W. Herreman
%
% Global instability theory may be useful when performing an experimental
% study on LDMI in cylinders. We consider that it may be helpfull to see how  
% such study is performed in practice using for example Matlab. 
%
% This is why we include 3 small programs as supplementary material to the
% article. 
%
%   1. demo_LDMI.m     (the present script)
%   2. LDMI3.m         (finding resonant waves & calculating matrix elements)
%   3. sigmamax_vs_om  (maximal growth rate as a function of libration frequency)
%
% Each program is commented. We decided to limit supplementary material to 
% these three small scripts, because is not difficult to modify the post-processing 
% step, to :
%   
%   - identify each resonant couple of modes.
%   - study how growth rates vary over E, epsil, p intervals 
%
% etc. As an example, we study LDMI in a tripolarly deformed cylinder of aspect
% ratio 2 and perform a libration frequency scan. 
%
%
% 1. CALCULATION STEP : 
% ---------------------

% We find (many) inertial wave pairs that may couple through LDMI, up to a 
% certain resolution, and calculate all the necessary matrix elements, to
% know how they would interact. 

n=2;
h=2;

COOR=LDMI3(n,h);

% This takes a while, but only needs to be done once per cylinder and per
% considered multipolarity. COOR is a big data-structure (see LDMI3 for details) 
% that may be stored for further use.   

% 2. POSTPROCESSING STEPS : 
% -------------------------
%
% In a postprocessing step, one can now fix/vary all the other parameters. 
% For example, if we want to know the maximum viscous growth rate over a large 
% range of libration frequencies, we fix

epsil=1; %libration amplitude 
p=0.3;   %deformation amplitude
E=1e-4;  %Ekman number
j=1;     %multiple of libration frequency (integer as in article) 

cl=1;    %there are four classes of interacting modes, depending on the sign of
         %lambda1 and lambda2. The first class of modes are the most unstable. 
         %classes 3 and 4 are stable.  
         
% Next we launch the script          
         
sigmamax_vs_om(epsil,p,E,j,cl,COOR)

% to find a plot in which this maximal growth rate is plotted as a function
% of omega. 




