function sigmamax_vs_om(epsil,p,E,j,cl,COOR)

%%  Author : W. Herreman
%
% epsil : libration amplitude       
% p     : deformation amplitude    p << 1 ideally
% E     : Ekman number
% j     : integer as in the article. 
% cl    : class of couplings (1 usually most unstable)
% COOR  : large structure containing all information of possibly 
%         resonant configurations, necessary fo post-processing

% The output is a figure that shows tha maximal growth rate as a function
% of the libration frequency omega. It is not difficult to output tables, 
% that allow to identify all couplings separately, but this is not done here.   


% measure size of dataset
[nzmax,lm1,cls]=size(COOR);


% define explored frequency range
omlist=linspace(2,5,200);            % now omega in [2,5]
sigmamax=zeros(size(omlist));

% for all pairs of modes within class cl
for tl=1:nzmax
    for tm1=1:lm1 
        
        coor=COOR(tl,tm1,cl);
        n=coor.n;
        
        for nr=1:length(coor.lam1)
            
            % frequency of both waves
            lam1=coor.lam1(nr);
            lam2=coor.lam2(nr);
                            
            % frequency detuning 
            deltalist=(lam1+j*omlist-lam2)/2;       
            
            % libration angles
            dphi=epsil./omlist;                     
            
            % evaluate non viscous growth rate at perfect resonance 
            sigmanv=p*sqrt((epsil.*ffun(abs(j))*coor.N12(nr)/coor.J11(nr)-gfun(abs(j)).*coor.BT12(nr)/coor.J11(nr)).*(epsil.*ffun(abs(j))*coor.N21(nr)/coor.J22(nr)-gfun(abs(j)).*coor.BT21(nr)/coor.J22(nr)));   
            
            if real(sigmanv)>0 % only continue when this is non-zero
               
                % add viscous and detuning effects
                alpha1=sqrt(E)*coor.Gr1(nr)+E*coor.Gv1(nr) -1i*deltalist; 
                alpha2=sqrt(E)*coor.Gr2(nr)+E*coor.Gv2(nr) +1i*deltalist;
                     
                % calculate viscous growth rate
                sigmalist=-(alpha1+alpha2)/2+1/2*sqrt((alpha1-alpha2).^2+4*sigmanv.^2);

%                 %you can plot a curve for each coupling                 
%                 plot(omlist,real(sigmalist))
%                 hold all

                % filter the largest growth rate achieved up until now
                sigmamax=max(real([sigmalist;sigmamax]),[],1);
                     
                
            end
            
        end
        
    end
end
plot(omlist,sigmamax)
xlabel('omega')
ylabel('max(\sigma)')
hold all

    %% function f_j
    function res=ffun(jj)

        if mod(abs(jj),2)==1  %si j impair
            res=1/4*(besselj(abs(jj)-1,n*dphi)+besselj(abs(jj)+1,n*dphi));
        else
            res=1/4*(besselj(abs(jj)-1,n*dphi)+besselj(abs(jj)+1,n*dphi))*sign(jj);
        end

    end
    %% fonction g_j
    function res=gfun(jj)

        res=1/2*besselj(abs(jj),n*dphi)*sign(jj);

    end

end